<?php
/**
* @subpackage	com_articlelinked
* @author		Antonio Di Girolamo & Giampaolo Losito
* @copyright	Copyright (C) 2011 isApp.it. All rights reserved.
* @license		http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
* @link			http://www.isapp.it/article-link.html
*/
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport( 'joomla.application.component.model' );

class ArticlelinkedModelArticles extends JModel {
	
	var $db = null;
	var $_pagination = null;
	var $context = 'com_articlelinked.viewcontent';
	var $lists = null;
	
	function __construct($config) {
		$this->db =& JFactory::getDBO();
		parent::__construct($config);
	}
	
	function getArticles() {
		global $mainframe;

		// Initialize variables

		// Get some variables from the request
		$sectionid			= JRequest::getVar( 'sectionid', -1, '', 'int' );
		$option				= JRequest::getCmd( 'option' );
		$context			= $this->context;
		

		$where = $this->getWhere();
		$order = $this->getOrder();
		// Create the pagination object
		$pagination = $this->getPagination();

		// Get the articles
		$query = 'SELECT c.*, g.name AS groupname, cc.title AS name, u.name AS editor, f.content_id AS frontpage, s.title AS section_name, v.name AS author' .
				' FROM #__content AS c' .
				' LEFT JOIN #__categories AS cc ON cc.id = c.catid' .
				' LEFT JOIN #__sections AS s ON s.id = c.sectionid' .
				' LEFT JOIN #__groups AS g ON g.id = c.access' .
				' LEFT JOIN #__users AS u ON u.id = c.checked_out' .
				' LEFT JOIN #__users AS v ON v.id = c.created_by' .
				' LEFT JOIN #__content_frontpage AS f ON f.content_id = c.id' .
				$where .
				$order;
		$this->db->setQuery($query, $pagination->limitstart, $pagination->limit);
		$rows = $this->db->loadObjectList();

		// If there is a database query error, throw a HTTP 500 and exit
		if ($this->db->getErrorNum()) {
			JError::raiseError( 500, $this->db->stderr() );
			return false;
		}
		
		return $rows;
	}
	
	function getArticle($id) {
		$row = & JTable::getInstance('content');
		$row->load($id);

		require_once JPATH_ROOT.DS.'components'.DS.'com_content'.DS.'helpers'.DS.'route.php';
		$link = JRoute::_(ContentHelperRoute::getArticleRoute($row->id.'-'.$row->alias, $row->catid, $row->sectionid));
		
		$query = parse_url($link, PHP_URL_QUERY);
		if(strpos($query, '&amp;') !== false) {
		   $query = str_replace('&amp;','&',$query);
		}
		parse_str($query, $query);
		if(isset($query['Itemid'])) {
			unset($query['Itemid']);
		}
		$row->link = 'index.php?'.http_build_query($query);
		
		return $row;
	}
	
	function getOrder() {
		global $mainframe;
		
		$filter_order		= $mainframe->getUserStateFromRequest( $this->context.'filter_order',		'filter_order',		'',	'cmd' );
		$filter_order_Dir	= $mainframe->getUserStateFromRequest( $this->context.'filter_order_Dir',	'filter_order_Dir',	'',	'word' );
		
		// ensure we have a valid value for filter_order
		if (!in_array($filter_order, array('c.title', 'c.state', 'frontpage', 'c.ordering', 'groupname',
									'section_name', 'cc.title', 'author', 'c.created', 'c.hits', 'c.id')))
		{
			$filter_order = 'section_name';

		}

		if ($filter_order == 'c.ordering') {
			$order = ' ORDER BY section_name, cc.title, c.ordering '. $filter_order_Dir;
		} else {
			$order = ' ORDER BY '. $filter_order .' '. $filter_order_Dir .', section_name, cc.title, c.ordering';
		}
		
		return $order;
	}
	
	function getWhere() {
		global $mainframe;
		
		$filter_state		= $mainframe->getUserStateFromRequest( $this->context.'filter_state',		'filter_state',		'',	'word' );
		$catid				= $mainframe->getUserStateFromRequest( $this->context.'catid',			'catid',			0,	'int' );
		$filter_sectionid	= $mainframe->getUserStateFromRequest( $this->context.'filter_sectionid',	'filter_sectionid',	-1,	'int' );
		$search				= $mainframe->getUserStateFromRequest( $this->context.'search',			'search',			'',	'string' );
		$filter_authorid	= $mainframe->getUserStateFromRequest( $this->context.'filter_authorid',	'filter_authorid',	0,	'int' );
		if (strpos($search, '"') !== false) {
			$search = str_replace(array('=', '<'), '', $search);
		}
		$search = JString::strtolower($search);

		//$where[] = "c.state >= 0";
		$where[] = 'c.state != -2';

		/*
		 * Add the filter specific information to the where clause
		 */
		// Section filter
		if ($filter_sectionid >= 0) {
			$where[] = 'c.sectionid = ' . (int) $filter_sectionid;
		}
		// Category filter
		if ($catid > 0) {
			$where[] = 'c.catid = ' . (int) $catid;
		}
		// Author filter
		if ($filter_authorid > 0) {
			$where[] = 'c.created_by = ' . (int) $filter_authorid;
		}
		// Content state filter
		if ($filter_state) {
			if ($filter_state == 'P') {
				$where[] = 'c.state = 1';
			} else {
				if ($filter_state == 'U') {
					$where[] = 'c.state = 0';
				} else if ($filter_state == 'A') {
					$where[] = 'c.state = -1';
				} else {
					$where[] = 'c.state != -2';
				}
			}
		}
		// Keyword filter
		if ($search) {
			$where[] = '(LOWER( c.title ) LIKE '.$this->db->Quote( '%'.$this->db->getEscaped( $search, true ).'%', false ) .
				' OR c.id = ' . (int) $search . ')';
		}

		// Build the where clause of the content record query
		$where = (count($where) ? ' WHERE '.implode(' AND ', $where) : '');
		
		return $where;
	}
	
	function getTotal() {
		// Get the total number of records
		$query = 'SELECT COUNT(*)' .
				' FROM #__content AS c' .
				' LEFT JOIN #__categories AS cc ON cc.id = c.catid' .
				' LEFT JOIN #__sections AS s ON s.id = c.sectionid' .
				$this->getWhere();
		$this->db->setQuery($query);
		$total = $this->db->loadResult();
		
		return $total; 
	}
	
	function getLists() {
		global $mainframe;
		
		$catid 				= $mainframe->getUserStateFromRequest( $this->context.'catid', 				'catid', 			0, 	'int' );
		$filter_sectionid	= $mainframe->getUserStateFromRequest( $this->context.'filter_sectionid',	'filter_sectionid',	-1,	'int' );
		$filter_authorid	= $mainframe->getUserStateFromRequest( $this->context.'filter_authorid',	'filter_authorid',	0,	'int' );
		$filter_state		= $mainframe->getUserStateFromRequest( $this->context.'filter_state',		'filter_state',		'',	'word' );
		$search				= $mainframe->getUserStateFromRequest( $this->context.'search',				'search',			'',	'string' );
		$filter_order		= $mainframe->getUserStateFromRequest( $this->context.'filter_order',		'filter_order',		'',	'cmd' );
		$filter_order_Dir	= $mainframe->getUserStateFromRequest( $this->context.'filter_order_Dir',	'filter_order_Dir',	'',	'word' );
		$filter	= ' WHERE s.published = 1';
		
		if ($filter_sectionid >= 0) {
			$filter = ' AND cc.section = '. (int) $filter_sectionid;
		}
		
		// get list of categories for dropdown filter
		$query = 'SELECT cc.id AS value, cc.title AS text, section' .
				' FROM #__categories AS cc' .
				' INNER JOIN #__sections AS s ON s.id = cc.section ' .
				$filter .
				' ORDER BY s.ordering, cc.ordering';
		$lists['catid'] = $this->filterCategory($query, $catid);

		// get list of sections for dropdown filter
		$javascript = 'onchange="document.adminForm.submit();"';
		$lists['sectionid'] = JHTML::_('list.section', 'filter_sectionid', $filter_sectionid, $javascript);

		// get list of Authors for dropdown filter
		$query = 'SELECT c.created_by, u.name' .
				' FROM #__content AS c' .
				' INNER JOIN #__sections AS s ON s.id = c.sectionid' .
				' LEFT JOIN #__users AS u ON u.id = c.created_by' .
				' WHERE c.state <> -1' .
				' AND c.state <> -2' .
				' GROUP BY u.name' .
				' ORDER BY u.name';
		$authors[] = JHTML::_('select.option', '0', '- '.JText::_('Select Author').' -', 'created_by', 'name');
		$this->db->setQuery($query);
		$authors = array_merge($authors, $this->db->loadObjectList());
		$lists['authorid'] = JHTML::_('select.genericlist',  $authors, 'filter_authorid', 'class="inputbox" size="1" onchange="document.adminForm.submit( );"', 'created_by', 'name', $filter_authorid);

		// state filter
		$lists['state'] = JHTML::_('grid.state', $filter_state, 'Published', 'Unpublished', 'Archived');

		// table ordering
		$lists['order_Dir']	= $filter_order_Dir;
		$lists['order']		= $filter_order;

		// search filter
		$lists['search'] = $search;
		
		return $lists;
	}
	
	/**
	 * Method to get a pagination object for the weblinks
	 *
	 * @access public
	 * @return integer
	 */
	function getPagination()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->_pagination))
		{
			global $mainframe;
			
			$limit		= $mainframe->getUserStateFromRequest('global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
			$limitstart	= $mainframe->getUserStateFromRequest($this->context.'limitstart', 'limitstart', 0, 'int');
	
			// In case limit has been changed, adjust limitstart accordingly
			$limitstart = ( $limit != 0 ? (floor($limitstart / $limit) * $limit) : 0 );
		
			jimport('joomla.html.pagination');
			$this->_pagination = new JPagination( $this->getTotal(), $limitstart, $limit );
		}

		return $this->_pagination;
	}
	
	function filterCategory($query, $active = NULL)
	{
		$categories[] = JHTML::_('select.option', '0', '- '.JText::_('Select Category').' -');
		$this->db->setQuery($query);
		$categories = array_merge($categories, $this->db->loadObjectList());

		$category = JHTML::_('select.genericlist',  $categories, 'catid', 'class="inputbox" size="1" onchange="document.adminForm.submit( );"', 'value', 'text', $active);

		return $category;
	}
	
	function findItemid($id, $catid = 0, $sectionid = 0)
	{
		$needles = array(
			'article'  => (int) $id,
			'category' => (int) $catid,
			'section'  => (int) $sectionid,
		);
		
		$component =& JComponentHelper::getComponent('com_content');

		$menus	= &JApplication::getMenu('site', array());
		$items	= $menus->getItems('componentid', $component->id);

		$match = array();

		foreach($needles as $needle => $id)
		{
			foreach($items as $item)
			{
				if ((@$item->query['view'] == $needle) && (@$item->query['id'] == $id)) {
					$match[$item->id] = $item->name;
				}
			}
		}

		return $match;
	}
}